@@ -1,6 +1,6 @@
-use crate::extractor::Value;
 use crate::filter::Filter;
 use crate::state::StateManager;
+use crate::Value;
 
 pub struct FlipFlopFilter {
     state: bool,
