@@ -1,6 +1,6 @@
-use crate::extractor::Value;
 use crate::filter::Filter;
 use crate::state::StateManager;
+use crate::Value;
 
 pub struct U16IsEqualFilter {
     value: u16,
@@ -17,7 +17,7 @@ impl Filter for U16IsEqualFilter {
         let value = match value {
             Value::U16(value) => value,
             _ => {
-                panic!("Wrong value provided for u16 is equal matcher.");
+                panic!("Wrong value provided for u16 is equal filter.");
             }
         };
 
