@@ -2,7 +2,6 @@ use ross_protocol::packet::Packet;
 
 use crate::producer::Producer;
 use crate::state::StateManager;
-use crate::DeviceInfo;
 use crate::Value;
 
 pub struct NoneProducer {}
@@ -17,8 +16,8 @@ impl Producer for NoneProducer {
     fn produce(
         &self,
         _value: &Value,
-        _device_info: &DeviceInfo,
         _state_manager: &StateManager,
+        _device_address: u16,
     ) -> Option<Packet> {
         None
     }
